==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ru-RU/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Этот пользователь может войти в систему',
    'activated_disabled_help_text' => 'Вы не можете редактировать статус активации своей учетной записи.',
    'assets_user'       => 'Актив привязан к :name',
    'bulk_update_warn'	=> 'Вы собираетесь изменить свойства :user_count пользователей. Пожалуйста, обратите внимание, что вы не сможете изменить ваши собственные атрибуты используя эту форму. Если вам нужно изменить атрибуты своего профиля, то внесите изменения отдельно.',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько пользователей за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений.',
    'current_assets'    => 'Активы, выданные данному пользователю',
    'clone'             => 'Клонировать пользователя',
    'contact_user'      => 'Связаться с :name',
    'edit'              => 'Редактировать пользователя',
    'filetype_info'     => 'Разрешенные типы файлов: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История для :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Нажмите здесь, чтобы восстановить их.',
    'last_login'        => 'Последний вход',
    'ldap_config_text'  => 'Параметры конфигурации LDAP можно найти Администратор > Параметры. Выбранное местоположение будет установлено для всех импортируемых пользователей. (Необязательно).',
    'print_assigned'    => 'Печать всех назначенных',
    'email_assigned'    => 'Список адресов электронной почты всех назначенных',
    'user_notified'     => 'Пользователю был отправлен по электронной почте список назначенных им в данный момент элементов.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Включить этого пользователя при автоматическом назначении лицензий',
    'auto_assign_help'  => 'Пропустить этого пользователя в автоматическом назначении лицензий',
    'software_user'     => 'Программное обеспечение привязано к :name',
    'send_email_help'   => 'Вы должны указать адрес электронной почты для этого пользователя, чтобы отправить им учетные данные. Электронная почта может быть выполнена только при создании пользователя. Пароли хранятся в одностороннем хэше и не могут быть восстановлены после сохранения.',
    'view_user'         => 'Показать пользователя :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Ваши текущие параметры администрирования разрешают избирательное применение двухфакторной аутентификации.  ',
    'two_factor_enrolled' => 'Устройство 2FA зарегистрировано ',
    'two_factor_active'   => '2FA Активный ',
    'user_deactivated'  => 'Пользователь не может войти',
    'user_activated'  => 'Пользователь может войти',
    'activation_status_warning' => 'Не изменяйте статус активации',
    'group_memberships_helpblock' => 'Только суперпользователи могут изменять членство группы.',
    'superadmin_permission_warning' => 'Только суперпользователи могут предоставить права суперпользователя.',
    'admin_permission_warning' => 'Только пользователи с правами администратора могут предоставить административный доступ пользователю.',
    'remove_group_memberships' => 'Удалить членство в группах',
    'warning_deletion_information' => 'Вы собираетесь отвязать ВСЕ элементы от :count пользователя(ей) перечисленных ниже. Имена супер-администраторов выделены красным цветом.',
    'update_user_assets_status' => 'Обновить все активы для этих пользователей до этого статуса',
    'checkin_user_properties' => 'Отвязать все свойства связанные с этими пользователями',
    'remote_label'   => 'Это удаленный пользователь',
    'remote'   => 'Удаленное',
    'remote_help' => 'Это может быть полезно, если вам нужно фильтровать удалённых пользователей, которые никогда или редко появляются в вашем физическом местоположении.',
    'not_remote_label' => 'Это не удаленный пользователь',
    'vip_label' => 'VIP пользователь',
    'vip_help' => 'Это может быть полезно для обозначения важных людей в вашей организации, если вы хотите обрабатывать их обращения особым образом.',
    'create_user' => 'Создать пользователя',
    'create_user_page_explanation' => 'Это информация об учетной записи, которую вы будете использовать для первого входа на сайт.',
    'email_credentials' => 'Учётные данные электронной почты',
    'email_credentials_text' => 'Отправить мои учетные данные на указанный выше адрес электронной почты',
    'next_save_user' => 'Далее: Сохранить пользователя',
    'all_assigned_list_generation' => 'Создано:',
    'email_user_creds_on_create' => 'Отправить этому пользователю его данные по почте?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/ru-RU/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Этот пользователь может войти в систему',
    'activated_disabled_help_text' => 'Вы не можете редактировать статус активации своей учетной записи.',
    'assets_user'       => 'Актив привязан к :name',
    'bulk_update_warn'	=> 'Вы собираетесь изменить свойства :user_count пользователей. Пожалуйста, обратите внимание, что вы не сможете изменить ваши собственные атрибуты используя эту форму. Если вам нужно изменить атрибуты своего профиля, то внесите изменения отдельно.',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько пользователей за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений.',
    'current_assets'    => 'Активы, выданные данному пользователю',
    'clone'             => 'Клонировать пользователя',
    'contact_user'      => 'Связаться с :name',
    'edit'              => 'Редактировать пользователя',
    'filetype_info'     => 'Разрешенные типы файлов: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История для :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Нажмите здесь, чтобы восстановить их.',
    'last_login'        => 'Последний вход',
    'ldap_config_text'  => 'Параметры конфигурации LDAP можно найти Администратор > Параметры. Выбранное местоположение будет установлено для всех импортируемых пользователей. (Необязательно).',
    'print_assigned'    => 'Печать всех назначенных',
    'email_assigned'    => 'Список адресов электронной почты всех назначенных',
    'user_notified'     => 'Пользователю был отправлен по электронной почте список назначенных им в данный момент элементов.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Включить этого пользователя при автоматическом назначении лицензий',
    'auto_assign_help'  => 'Пропустить этого пользователя в автоматическом назначении лицензий',
    'software_user'     => 'Программное обеспечение привязано к :name',
    'view_user'         => 'Показать пользователя :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Ваши текущие параметры администрирования разрешают избирательное применение двухфакторной аутентификации.  ',
    'two_factor_enrolled' => 'Устройство 2FA зарегистрировано ',
    'two_factor_active'   => '2FA Активный ',
    'user_deactivated'  => 'Пользователь не может войти',
    'user_activated'  => 'Пользователь может войти',
    'activation_status_warning' => 'Не изменяйте статус активации',
    'group_memberships_helpblock' => 'Только суперпользователи могут изменять членство группы.',
    'superadmin_permission_warning' => 'Только суперпользователи могут предоставить права суперпользователя.',
    'admin_permission_warning' => 'Только пользователи с правами администратора могут предоставить административный доступ пользователю.',
    'remove_group_memberships' => 'Удалить членство в группах',
    'warning_deletion_information' => 'Вы собираетесь отвязать ВСЕ элементы от :count пользователя(ей) перечисленных ниже. Имена супер-администраторов выделены красным цветом.',
    'update_user_assets_status' => 'Обновить все активы для этих пользователей до этого статуса',
    'checkin_user_properties' => 'Отвязать все свойства связанные с этими пользователями',
    'remote_label'   => 'Это удаленный пользователь',
    'remote'   => 'Удаленное',
    'remote_help' => 'Это может быть полезно, если вам нужно фильтровать удалённых пользователей, которые никогда или редко появляются в вашем физическом местоположении.',
    'not_remote_label' => 'Это не удаленный пользователь',
    'vip_label' => 'VIP пользователь',
    'vip_help' => 'Это может быть полезно для обозначения важных людей в вашей организации, если вы хотите обрабатывать их обращения особым образом.',
    'create_user' => 'Создать пользователя',
    'create_user_page_explanation' => 'Это информация об учетной записи, которую вы будете использовать для первого входа на сайт.',
    'email_credentials' => 'Учётные данные электронной почты',
    'email_credentials_text' => 'Отправить мои учетные данные на указанный выше адрес электронной почты',
    'next_save_user' => 'Далее: Сохранить пользователя',
    'all_assigned_list_generation' => 'Создано:',
    'email_user_creds_on_create' => 'Отправить этому пользователю его данные по почте?',
    'department_manager' => 'Department Manager',
];
